@@ -1048,7 +1048,7 @@ gnome_client_module_info_get (void)
 		NULL, NULL
 	};
 
-	module_info.expansion1 = gnome_client_module_get_goption_group;
+	module_info.get_goption_group_func = gnome_client_module_get_goption_group;
 
 	if (module_info.requirements == NULL) {
 		static GnomeModuleRequirement req[3];
